@@ -3,7 +3,7 @@ from .verbose import Verbose
 # LRU cache class
 class FIFOCache:
 
-    def __init__(self, capacity,lock,verbose):
+    def __init__(self, capacity,lock,verbose=0):
         # capacity: capacity of cache
         # Initialize all variable
         self.capacity = capacity
