@@ -4,7 +4,7 @@ from .verbose import Verbose
 # LRU cache class
 class LIFOCache:
 
-    def __init__(self, capacity,lock):
+    def __init__(self, capacity,lock,verbose=0):
         # capacity: capacity of cache
         # Initialize all variable
         self.capacity = capacity
